pub struct MigrationStatus {
pub current_version: u32,
pub applied_count: usize,
}Expand description
Snapshot of the current migration-ledger state.
Fields
current_version: u32The highest version number that has been applied, or 0 if none.
applied_count: usizeThe number of migration versions that have been applied.